Class: RuCaptcha::Configuration
- Inherits:
-
Object
- Object
- RuCaptcha::Configuration
- Defined in:
- lib/rucaptcha/configuration.rb
Instance Attribute Summary collapse
-
#cache_store ⇒ Object
Store Captcha code where, this config more like Rails config.cache_store default: Rails application config.cache_store.
-
#difficulty ⇒ Object
Hard mode, default: 5, allows: [1..10].
-
#expires_in ⇒ Object
rucaptcha expire time, default 2 minutes.
-
#length ⇒ Object
Chars length: default 5, allows: [3..7].
-
#skip_cache_store_check ⇒ Object
skip_cache_store_check, default: false.
Instance Attribute Details
#cache_store ⇒ Object
Store Captcha code where, this config more like Rails config.cache_store default: Rails application config.cache_store
5 6 7 |
# File 'lib/rucaptcha/configuration.rb', line 5 def cache_store @cache_store end |
#difficulty ⇒ Object
Hard mode, default: 5, allows: [1..10]
11 12 13 |
# File 'lib/rucaptcha/configuration.rb', line 11 def difficulty @difficulty end |
#expires_in ⇒ Object
rucaptcha expire time, default 2 minutes
7 8 9 |
# File 'lib/rucaptcha/configuration.rb', line 7 def expires_in @expires_in end |
#length ⇒ Object
Chars length: default 5, allows: [3..7]
9 10 11 |
# File 'lib/rucaptcha/configuration.rb', line 9 def length @length end |
#skip_cache_store_check ⇒ Object
skip_cache_store_check, default: false
13 14 15 |
# File 'lib/rucaptcha/configuration.rb', line 13 def skip_cache_store_check @skip_cache_store_check end |